@@ -10,32 +10,32 @@ ported to pure python.
 
 An example::
 
-    import iadpython as iad
+    >>> import iadpython as iad
 
-    mu_s = 10  # scattering coefficient [1/mm]
-    mu_a = 0.1 # absorption coefficient [1/mm]
-    g = 0.9    # scattering anisotropy
-    d = 1      # thickness mm
+    >>> mu_s = 10  # scattering coefficient [1/mm]
+    >>> mu_a = 0.1 # absorption coefficient [1/mm]
+    >>> g = 0.9    # scattering anisotropy
+    >>> d = 1      # thickness mm
 
-    a = mu_s/(mu_a+mu_s)
-    b = mu_s/(mu_a+mu_s) * d
+    >>> a = mu_s/(mu_a+mu_s)
+    >>> b = mu_s/(mu_a+mu_s) * d
 
-    # air / glass / sample / glass / air
-    s = iadpython.Sample(a=a, b=b, g=g, n=1.4, n_above=1.5, n_below=1.5)
-    ur1, ut1, uru, utu = s.rt()
+    >>> # air / glass / sample / glass / air
+    >>> s = iadpython.Sample(a=a, b=b, g=g, n=1.4, n_above=1.5, n_below=1.5)
+    >>> ur1, ut1, uru, utu = s.rt()
 
-    print('Collimated light incident perpendicular to sample')
-    print('  total reflection = %.5f' % ur1)
-    print('  total transmission = %.5f' % ut1)
+    >>> print('Collimated light incident perpendicular to sample')
+    >>> print('  total reflection = %.5f' % ur1)
+    >>> print('  total transmission = %.5f' % ut1)
 
-    print('Diffuse light incident on sample')
-    print('  total reflection = %.5f' % uru)
-    print('  total transmission = %.5f' % utu)
+    >>> print('Diffuse light incident on sample')
+    >>> print('  total reflection = %.5f' % uru)
+    >>> print('  total transmission = %.5f' % utu)
 """
-__version__ = '0.5.1'
+__version__ = '0.5.2'
 __author__ = 'Scott Prahl'
 __email__ = 'scott.prahl@oit.edu'
-__copyright__ = 'Copyright 2018-22, Scott Prahl'
+__copyright__ = 'Copyright 2018-23, Scott Prahl'
 __license__ = 'MIT'
 __url__ = 'https://github.com/scottprahl/iadpython.git'
 
